@@ -16,7 +16,7 @@ import numpy as np
 from spatialmath.base import symbolic as sym
 
 # valid scalar types
-_scalartypes = (int, np.int64, float, np.float64) + sym.symtype
+_scalartypes = (int, np.integer, float, np.floating) + sym.symtype
 
 def isscalar(x):
     """
@@ -38,6 +38,24 @@ def isscalar(x):
     """
     return isinstance(x, _scalartypes)
 
+def isinteger(x):
+    """
+    Test if argument is a scalar integer
+
+    :param x: value to test
+    :return: whether value is a scalar
+    :rtype: bool
+
+    ``isinteger(x)`` is ``True`` if ``x`` is a Python or numPy int or real float.
+
+    .. runblock:: pycon
+
+        >>> from spatialmath.base import isscalar
+        >>> isinteger(1)
+        >>> isinteger(1.2)
+
+    """
+    return isinstance(x, (int, np.integer))
 
 def assertmatrix(m, shape=None):
     """
@@ -113,7 +131,7 @@ def ismatrix(m, shape):
         return False
     return True
 
-def getmatrix(m, shape):
+def getmatrix(m, shape, dtype=np.float64):
     r"""
     Convert argument to 2D array
 
@@ -159,13 +177,13 @@ def getmatrix(m, shape):
         mshape = m.shape
 
         if (shape[0] is None or shape[0] == mshape[0]) and (shape[1] is None or shape[1] == mshape[1]):
-                return m
+                return np.array(m, dtype=dtype)
         else:
             raise ValueError(f"expecting {shape} but got {mshape}")
 
     elif isvector(m):
             # passed a 1D array
-            m = getvector(m)
+            m = getvector(m, dtype=dtype)
             if shape[0] is not None and shape[1] is not None:
                 if len(m) == np.prod(shape):
                     return m.reshape(shape)
